@@ -9,7 +9,7 @@
 # WARRANTIES OR REPRESENTATIONS OF ANY KIND, either express or
 # implied. See the LICENSE-MIT and LICENSE-APACHE files for the
 # specific language governing permissions and limitations under
-# each license.import unittest
+# each license.
 
 import os
 import io
@@ -40,7 +40,7 @@ ALTERNATIVE_INGREDIENT_TEST_FILE = os.path.join(FIXTURES_DIR, "cloud.jpg")
 
 class TestC2paSdk(unittest.TestCase):
     def test_sdk_version(self):
-        self.assertIn("0.59.1", sdk_version())
+        self.assertIn("0.60.1", sdk_version())
 
 
 class TestReader(unittest.TestCase):
@@ -126,9 +126,6 @@ class TestReader(unittest.TestCase):
     def test_reader_close_cleanup(self):
         with open(self.testPath, "rb") as file:
             reader = Reader("image/jpeg", file)
-            # Store references to internal objects
-            reader_ref = reader._reader
-            stream_ref = reader._own_stream
             # Close the reader
             reader.close()
             # Verify all resources are cleaned up
@@ -144,6 +141,23 @@ class TestReader(unittest.TestCase):
         with self.assertRaises(Error):
             reader.resource_to_stream("", io.BytesIO(bytearray()))
 
+    def test_read_dng_from_stream(self):
+        test_path = os.path.join(self.data_dir, "C.dng")
+        with open(test_path, "rb") as file:
+            file_content = file.read()
+
+        with Reader("dng", io.BytesIO(file_content)) as reader:
+            # Just run and verify there is no crash
+            json.loads(reader.json())
+
+    def test_read_dng_file_from_path(self):
+        test_path = os.path.join(self.data_dir, "C.dng")
+
+        # Create reader with the file content
+        with Reader(test_path) as reader:
+            # Just run and verify there is no crash
+            json.loads(reader.json())
+
     def test_read_all_files(self):
         """Test reading C2PA metadata from all files in the fixtures/files-for-reading-tests directory"""
         reading_dir = os.path.join(self.data_dir, "files-for-reading-tests")
@@ -956,6 +970,7 @@ class TestBuilderWithSigner(unittest.TestCase):
             # Verify the first ingredient's title matches what we set
             first_ingredient = active_manifest["ingredients"][0]
             self.assertEqual(first_ingredient["title"], "Test Ingredient")
+            self.assertNotIn("thumbnail", first_ingredient)
 
         builder.close()
 
@@ -1791,7 +1806,10 @@ class TestLegacyAPI(unittest.TestCase):
         ingredient_data = json.loads(ingredient_json_with_dir)
         self.assertEqual(ingredient_data["title"], INGREDIENT_TEST_FILE_NAME)
         self.assertEqual(ingredient_data["format"], "image/jpeg")
-        self.assertIn("thumbnail", ingredient_data)
+        self.assertNotIn("thumbnail", ingredient_data)
+
+        # Reset setting
+        load_settings('{"builder": { "thumbnail": {"enabled": true}}}')
 
     def test_compare_read_ingredient_file_with_builder_added_ingredient(self):
         """Test reading a C2PA ingredient from a file."""
